==> mogene10sttranscriptcluster.db_2.0.2.tar.gz: mogene10sttranscriptcluster.db/man/mogene10sttranscriptcluster_dbconn.Rd <==
\name{mogene10sttranscriptcluster_dbconn}

\alias{mogene10sttranscriptcluster_dbconn}
\alias{mogene10sttranscriptcluster_dbfile}
\alias{mogene10sttranscriptcluster_dbschema}
\alias{mogene10sttranscriptcluster_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  mogene10sttranscriptcluster_dbconn()
  mogene10sttranscriptcluster_dbfile()
  mogene10sttranscriptcluster_dbschema(file="", show.indices=FALSE)
  mogene10sttranscriptcluster_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{mogene10sttranscriptcluster_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{mogene10sttranscriptcluster_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{mogene10sttranscriptcluster_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{mogene10sttranscriptcluster_dbschema} prints the schema definition of the
  package annotation DB.

  \code{mogene10sttranscriptcluster_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{mogene10sttranscriptcluster_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{mogene10sttranscriptcluster_dbfile}: a character string with the path to the
  package annotation DB.

  \code{mogene10sttranscriptcluster_dbschema}: none (invisible \code{NULL}).

  \code{mogene10sttranscriptcluster_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(mogene10sttranscriptcluster_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by mogene10sttranscriptcluster_dbconn() was created with:
  dbConnect(SQLite(), dbname=mogene10sttranscriptcluster_dbfile(), cache_size=64000, synchronous=0)

  mogene10sttranscriptcluster_dbschema()

  mogene10sttranscriptcluster_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> mogene10sttranscriptcluster.db_6.0.1.tar.gz: mogene10sttranscriptcluster.db/man/mogene10sttranscriptcluster_dbconn.Rd <==

\name{mogene10sttranscriptcluster_dbconn}

\alias{mogene10sttranscriptcluster_dbconn}
\alias{mogene10sttranscriptcluster_dbfile}
\alias{mogene10sttranscriptcluster_dbschema}
\alias{mogene10sttranscriptcluster_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  mogene10sttranscriptcluster_dbconn()
  mogene10sttranscriptcluster_dbfile()
  mogene10sttranscriptcluster_dbschema(file="", show.indices=FALSE)
  mogene10sttranscriptcluster_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{mogene10sttranscriptcluster_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{mogene10sttranscriptcluster_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{mogene10sttranscriptcluster_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{mogene10sttranscriptcluster_dbschema} prints the schema definition of the
  package annotation DB.

  \code{mogene10sttranscriptcluster_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{mogene10sttranscriptcluster_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{mogene10sttranscriptcluster_dbfile}: a character string with the path to the
  package annotation DB.

  \code{mogene10sttranscriptcluster_dbschema}: none (invisible \code{NULL}).

  \code{mogene10sttranscriptcluster_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(mogene10sttranscriptcluster_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by mogene10sttranscriptcluster_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=mogene10sttranscriptcluster_dbfile(), cache_size=64000,
  synchronous=0)

  mogene10sttranscriptcluster_dbschema()

  mogene10sttranscriptcluster_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
